[tor-bugs] #5824 [Tor Bridge]: Stop reporting relay-only statistics as a bridge
Tor Bug Tracker & Wiki
torproject-admin at torproject.org
Thu May 10 08:53:11 UTC 2012
#5824: Stop reporting relay-only statistics as a bridge
------------------------+---------------------------------------------------
Reporter: karsten | Owner:
Type: defect | Status: new
Priority: minor | Milestone:
Component: Tor Bridge | Version:
Keywords: | Parent:
Points: | Actualpoints:
------------------------+---------------------------------------------------
Some bridges report statistics that were originally designed for relays
only. We throw these statistics away in the sanitizing process, so they
don't end up in the tarballs. But the cleaner approach would be to not
report them at all.
Here's how the patch could look like; I can make a proper patch with
changes file later:
{{{
diff --git a/src/or/config.c b/src/or/config.c
index ab4f160..2179117 100644
--- a/src/or/config.c
+++ b/src/or/config.c
@@ -1680,8 +1680,9 @@ options_act(const or_options_t *old_options)
time_t now = time(NULL);
int print_notice = 0;
- /* If we aren't acting as a server, we can't collect stats anyway. */
- if (!server_mode(options)) {
+ /* If we aren't acting as a server or if we are a bridge, we can't
+ * collect relay-only stats. */
+ if (!server_mode(options) || options->BridgeRelay) {
options->CellStatistics = 0;
options->DirReqStatistics = 0;
options->EntryStatistics = 0;
}}}
Is this something for 0.2.3.x or 0.2.4.x? Or do we not care at all?
--
Ticket URL: <https://trac.torproject.org/projects/tor/ticket/5824>
Tor Bug Tracker & Wiki <https://trac.torproject.org/>
The Tor Project: anonymity online
More information about the tor-bugs
mailing list